@@ -74,6 +74,7 @@ int local_only=0;
 int poll_time_min=TCPCGI_CLIENT_POLLTIME_MIN;
 int poll_time_max=TCPCGI_CLIENT_POLLTIME_MAX;
 char *userpass=NULL;
+char *proxyhost=NULL;
 struct sockinfo socks_info[128]; /* Needs to be num of elements as socks_poll in main() */
 
 
@@ -155,6 +156,7 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 	char *hex_cmd=NULL, *hex_session=NULL, *hex_data=NULL, *hex_path=NULL, *hex_host=NULL;
 	char *host=NULL, *port_str=NULL, *hostport;
 	char *http_auth=NULL;
+	char *http_realhost=NULL;
 	char buf[8192], *retbuf=NULL;
 	int fd;
 	int sink=0;
@@ -190,7 +192,12 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 		hex_host=hexcode(host, strlen(host));
 	}
 
-	fd=createconnection_tcp(http_host, http_port);
+	if (proxyhost) {
+		http_realhost=proxyhost;
+	} else {
+		http_realhost=http_host;
+	}
+	fd=createconnection_tcp(http_realhost, http_port);
 	if (fd<0) {
 		PERROR("connect");
 		PRINTERR("Couldn't connect!");
@@ -408,7 +415,7 @@ void sighandler(int sig) {
 
 int print_help(char *msg) {
 	fprintf(stderr, "Usage: tcpcgi -H host -f file -d dest [-P port] [-p port] [-m time]\n");
-	fprintf(stderr, "              [-x time] [-t time] [-b amt] [-U user] [-rigluvh]\n");
+	fprintf(stderr, "              [-x time] [-t time] [-b amt] [-V proxy] [-U user] [-rigluvh]\n");
 	fprintf(stderr, "    Options:\n");
 	fprintf(stderr, "         -H host      HTTP Server which has tcpcgi.cgi.\n");
 	fprintf(stderr, "         -f file      Full URL-relative on HTTP server to tcpcgi.cgi,\n");
@@ -428,6 +435,7 @@ int print_help(char *msg) {
 	fprintf(stderr, "                      should multiply the backoff time by this number,\n");
 	fprintf(stderr, "                      otherwise it's incremented by this amount (2 is the\n"); 
 	fprintf(stderr, "                      default).\n");
+	fprintf(stderr, "         -V proxy     Specify a host to send all HTTP traffic through.\n");
 	fprintf(stderr, "         -U user      Username and password to use for http authentication\n");
 	fprintf(stderr, "                      (must be in the form of user:pass).\n");
 	fprintf(stderr, "         -r           Specify that the backoff algorithm reset when remote\n");
@@ -488,7 +496,7 @@ int main(int argc, char **argv) {
 	pid_t chpid;
 #endif
 
-	while ((ch=getopt(argc, argv, "H:f:P:p:d:m:x:t:b:U:vgriulh"))!=-1) {
+	while ((ch=getopt(argc, argv, "H:f:P:p:d:m:x:t:b:V:U:vgriulh"))!=-1) {
 		switch (ch) {
 			case 'H':
 				http_host=strdup(optarg);
@@ -549,6 +557,9 @@ int main(int argc, char **argv) {
 			case 'U':
 				userpass=mimecode(optarg, strlen(optarg));
 				break;
+			case 'V':
+				proxyhost=strdup(optarg);
+				break;
 			case ':':
 			case '?':
 			case 'h':
