@@ -65,7 +65,7 @@ void *dehexcode(unsigned char *text, int *len) {
 
 	textcp=malloc(strlen(text)+1);
 	for (srcpos=0; srcpos<tl; srcpos++) {
-		if (text[srcpos]=='%') {
+		if (text[srcpos]=='#') {
 			srcpos++;
 			hex[0]=toupper(text[srcpos])-'0';
 			hex[1]=toupper(text[srcpos+1])-'0';
